Improve this doc

# Error: $parse:isecfn
Referencing Function Disallowed

    Referencing Function in Angular expressions is disallowed! Expression: {0}

## Description

Occurs when an expression attempts to access the 'Function' object (constructor for all functions in JavaScript).

Angular bans access to Function from within expressions since constructor access is a known way to execute arbitrary Javascript code.

To resolve this error, avoid Function access.